@@ -137,9 +137,15 @@ class BBBDL(InfoExtractor):
         # Parse metadata.xml
         meta = metadata.find('./meta')
         start_time = xpath_text(metadata, 'start_time')
+        recording_duration = float(xpath_text(metadata, './playback/duration')) / 1000.0  # in seconds
         title = xpath_text(meta, 'meetingName')
-        bbb_version = xpath_text(meta, 'bbb-origin-version').split(' ')[0]
-        self.to_screen("BBB version: " + bbb_version)
+        try:
+            bbb_origin_version = xpath_text(meta, 'bbb-origin-version')
+            if bbb_origin_version is not None:
+                bbb_version = bbb_origin_version.split(' ')[0]
+                self.to_screen("BBB version: " + bbb_version)
+        except Exception:
+            pass
 
         # Downloading Slides
         images = list()
@@ -186,6 +192,7 @@ class BBBDL(InfoExtractor):
             slide_path = video_id + '/' + slide_filename
             slide_ts_in = float(image.get('in'))
             slide_ts_out = float(image.get('out'))
+            slide_ts_duration = max(0.0, min(recording_duration - slide_ts_in, slide_ts_out - slide_ts_in))
 
             slides_infos.append(
                 Slide(
@@ -197,7 +204,7 @@ class BBBDL(InfoExtractor):
                     image_height,
                     slide_ts_in,
                     slide_ts_out,
-                    max(0, slide_ts_out - slide_ts_in),
+                    slide_ts_duration,
                     slide_annotations,
                 )
             )
